# Payload Generator

This is a package for generating different sized payloads of voice data that can be sent to the Ingestion Gateway to be enriched.

Each payload is populated with pseudo-data produced by the Faker library in Python. Verbatims created in each payload are capable of being enriched by the models in a given project by leveraging the given word bank.

## Usage

Make sure you have python installed on your machine (v2 or higher): https://www.python.org/downloads/

or using the following Homebrew command (only installs v3 or higher):

```
brew install python
```

### Installing the package

Either Python installation method above should automatically have `pip` installed. Confirm this by running

```
python3 -m pip --version
```

If this doesn't work, follow the following guide on getting it installed: https://packaging.python.org/en/latest/tutorials/installing-packages/#ensure-you-can-run-pip-from-the-command-line

Now you can install the package:

```
pip install payload-generator
```

### Command

This package requires three arguments:

1. the count of payloads/documents to be generated by the tool
2. the project ID the created payloads are intended to be uploaded to (in any CMP instance)
3. the path where the payloads will be kept (make sure any folder specified exists)

```
payload-generator [count] [project_id] [directory]
```

### Example

Create 5 payloads for the project `1010101` in the current directory

```
payload-generator 5 1010101 .
```

## Future Plans

- [ ] Tool can generate chat and text payloads
- [ ] Generated verbatims have comprehendable sentences

## Contributing

Feel free to iterate and introduce your own updates to this tool by creating a new feature branch and merging when ready!

Please reach out to @zkhatri if so for updating the package version to reflect these updates. Also feel free to suggest improvements!
